****************************
Maastricht Diffusion Toolbox
****************************

.. include:: ../README.rst

.. toctree::
   :maxdepth: 2
   :hidden:

   install
   getting_started
   home_folder
   FAQ <faq>
   credits
